summaryrefslogtreecommitdiff
path: root/nuttx/configs/olimex-lpc1766stk/src/up_boot.c
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/configs/olimex-lpc1766stk/src/up_boot.c')
-rw-r--r--nuttx/configs/olimex-lpc1766stk/src/up_boot.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/nuttx/configs/olimex-lpc1766stk/src/up_boot.c b/nuttx/configs/olimex-lpc1766stk/src/up_boot.c
index 9f4200004..0d265eaad 100644
--- a/nuttx/configs/olimex-lpc1766stk/src/up_boot.c
+++ b/nuttx/configs/olimex-lpc1766stk/src/up_boot.c
@@ -75,13 +75,13 @@
void lpc17_boardinitialize(void)
{
/* Configure SSP chip selects if 1) at least one SSP is enabled, and 2) the weak
* function lpc17_sspinitialize() has been brought into the link.
*/
#if defined(CONFIG_LPC17_SSP0) || defined(CONFIG_LPC17_SSP1)
- if (lpc17_sspinitialize)
+ if (lpc1766stk_sspinitialize)
{
- lpc17_sspinitialize();
+ lpc1766stk_sspinitialize();
}
#endif
@@ -75,13 +75,13 @@
{
/* Configure SSP chip selects if 1) at least one SSP is enabled, and 2) the weak
- * function lpc17_sspinitialize() has been brought into the link.
+ * function lpc1766stk_sspinitialize() has been brought into the link.
*/
#if defined(CONFIG_LPC17_SSP0) || defined(CONFIG_LPC17_SSP1)